@@ -26,8 +26,8 @@ def doReset():
     lemma_job = group(addLemmas.si(x) for x in chunk_dict(lemmas,10000))
     wfs,spells,trans = loadWF()
     wf_job = group(addWFS.si(x) for x in chunk_dict(wfs,10000))
-    spell_job = group(addSpells.si(x) for x in chunk_dict(spells,10000))
-    trans_job = group(addTrans.si(x) for x in chunk_dict(trans,10000))
+    spell_job = group(addSpells.si(x) for x in chunks(spells,10000))
+    trans_job = group(addTrans.si(x) for x in chunks(trans,10000))
     res = chain(loadCats.si(), lemma_job,wf_job,spell_job,trans_job,addRelationships.si(wfs))()
     res.get()
 
